/*
 * Copyright (C) 2011-2012 Koji Suzuki
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2.1 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//
//      A
//     ===
// F || G || B   DIG1 DIG2 DIG3 DIG4
//     ===
// E ||   || C
//     ===
//      D
//
// * anode common 
//
module seg7dec # (
		parameter ACTIVE_HIGH = 0
	) (
		input [3:0] DATA
                , output A
                , output B
                , output C
                , output D
                , output E
                , output F
                , output G
		);
	wire [6:0] seg7out;
					     //  ABCDEFG
	assign seg7out  = (DATA[3:0] == 4'h0) ? 7'b0000001
		         :(DATA[3:0] == 4'h1) ? 7'b1001111
		         :(DATA[3:0] == 4'h2) ? 7'b0010010
		         :(DATA[3:0] == 4'h3) ? 7'b0000110
		         :(DATA[3:0] == 4'h4) ? 7'b1001100
		         :(DATA[3:0] == 4'h5) ? 7'b0100100
		         :(DATA[3:0] == 4'h6) ? 7'b0100000
		         :(DATA[3:0] == 4'h7) ? 7'b0001101
		         :(DATA[3:0] == 4'h8) ? 7'b0000000
		         :(DATA[3:0] == 4'h9) ? 7'b0000100
		         :(DATA[3:0] == 4'hA) ? 7'b1111111
		         :(DATA[3:0] == 4'hB) ? 7'b1111111
		         :(DATA[3:0] == 4'hC) ? 7'b1111111
		         :(DATA[3:0] == 4'hD) ? 7'b1111111
		         :(DATA[3:0] == 4'hE) ? 7'b1111111
		         :                      7'b1111111
			 ;
			 
	assign A = ACTIVE_HIGH ? ~seg7out[6] : seg7out[6];
	assign B = ACTIVE_HIGH ? ~seg7out[5] : seg7out[6];
	assign C = ACTIVE_HIGH ? ~seg7out[4] : seg7out[6];
	assign D = ACTIVE_HIGH ? ~seg7out[3] : seg7out[6];
	assign E = ACTIVE_HIGH ? ~seg7out[2] : seg7out[6];
	assign F = ACTIVE_HIGH ? ~seg7out[1] : seg7out[6];
	assign G = ACTIVE_HIGH ? ~seg7out[0] : seg7out[6];
endmodule
